@@ -91,6 +91,10 @@ def artefacts(tmp_path):
             ["--device", "qemu-arm64be"],
             "qemu-arm64be.yaml",
         ),
+        (
+            ["--device", "qemu-arm64be", "--qemu-image", "docker.io/qemu/qemu:latest"],
+            "qemu-arm64be-qemu-image.yaml",
+        ),
         (
             ["--device", "qemu-armv5"],
             "qemu-armv5.yaml",
