@@ -30,7 +30,12 @@ def filter_options(options):
         "timeouts",
         "runtime",
         "image",
+        "qemu_image",
+        "save_outputs",
         "log_file",
+        "log_file_html",
+        "log_file_text",
+        "log_file_yaml",
         "results",
         "debug",
     ]
@@ -282,9 +287,27 @@ def setup_parser() -> argparse.ArgumentParser:
         default="docker.io/lavasoftware/lava-dispatcher:latest",
         help="Image to use",
     )
+    group.add_argument(
+        "--qemu-image", default=None, help="Use qemu from the given container image"
+    )
 
     group = parser.add_argument_group("output")
+    group.add_argument(
+        "--save-outputs",
+        default=False,
+        action="store_true",
+        help="Automatically save every outputs",
+    )
     group.add_argument("--log-file", default=None, type=Path, help="Store logs to file")
+    group.add_argument(
+        "--log-file-html", default=None, type=Path, help="Store logs to file as HTML"
+    )
+    group.add_argument(
+        "--log-file-text", default=None, type=Path, help="Store logs to file as text"
+    )
+    group.add_argument(
+        "--log-file-yaml", default=None, type=Path, help="Store logs to file as YAML"
+    )
     group.add_argument(
         "--results", default=None, type=Path, help="Save test results to file (JSON)"
     )
